import React, { useEffect, useMemo, useRef } from 'react'
import Taro from '@tarojs/taro'
import { View, Canvas } from '@tarojs/components'
import CodeText from './CodeText'
import { code128 } from './drawCode'
import './style.less'

export default (props) => {
  const { code, ratio, height, codeVisible = true } = props

  const id = useMemo(() => Math.random().toString(36).substring(2, 10), [])
  const canvasRef = useRef()
  const ctxRef = useRef()

  const { size, style } = useMemo(() => {
    const { safeArea, pixelRatio } = Taro.getSystemInfoSync()

    const rpxSize = {
      width: safeArea.width * ratio * pixelRatio,
      height: height * pixelRatio,
    }

    const pxStyle = {
      width: `${safeArea.width * ratio}px`,
      height: `${height}px`
    }

    return {
      size: rpxSize,
      style: pxStyle,
    }
  }, [ratio, height])

  useEffect(() => {
    Taro.nextTick(() => {
      const query = Taro.createSelectorQuery()
      query.select(`#${id}`).fields({ node: true }).exec((res) => {
        const canvas = res[0].node
        const ctx = canvas.getContext('2d')
        canvas.width = size.width
        canvas.height = size.height
        // ctx.scale(1, 1)

        canvasRef.current = canvas;
        ctxRef.current = ctx;

        if (code) {
          code128(ctx, code, size.width, size.height);
        }
      })
    })
  }, [code, size, id])

  return (
    <View className='barcode-box'>
      <Canvas style={style} type='2d' id={id}></Canvas>
      {
        codeVisible && <CodeText code={code} />
      }      
    </View>
  )
}
